@@ -80,12 +80,12 @@ char   *helpText[] = {
   "Information:  help     progress registers\n",
   "Macro:        calc     echo     if       macro    remark   reset\n",
 #if defined(DOSGRXGRAPHX) || defined(DOSTXTGRAPHX) || defined(LINUXGRAPHX) \
-    || defined(XWINGRAPHX)
+    || defined(XWINGRAPHX) || defined(SDLGRAPHX) || defined(STDGRAPHX)
   "Display:      clear    close    display  switch\n",
 #else
   "Display:      clear\n",
 #endif
-#if defined(__MAC__) || defined(XWINGRAPHX)
+#if defined(__MAC__) || defined(XWINGRAPHX) || defined(SDLGRAPHX) || defined(STDGRAPHX)
   "Others:       pqueue   wqueue   pspace   write\n",
 #else
   "Others:       pqueue   wqueue   pspace   shell    write\n",
@@ -95,12 +95,12 @@ char   *helpText[] = {
   "(ca)lc expr1[,expr2]   calculate expression(s) and echo result(s)\n",
   "(cl)ear                clear cdb screen\n",
 #if defined(DOSGRXGRAPHX) || defined(DOSTXTGRAPHX) || defined(LINUXGRAPHX) \
-    || defined(XWINGRAPHX)
+    || defined(XWINGRAPHX) || defined(SDLGRAPHX)
   "(clo)se                close right cdb panel and make left full-screen\n",
 #endif
   "(c)ontinue *           exit cdb and finish simulation\n",
 #if defined(CURSESGRAPHX) || defined(DOSTXTGRAPHX) || defined(DOSGRXGRAPHX) \
-    || defined(LINUXGRAPHX) || defined(XWINGRAPHX)
+    || defined(LINUXGRAPHX) || defined(XWINGRAPHX) || defined(SDLGRAPHX) || defined(STDGRAPHX)
   "(d)isplay clear|on|off|nnn\n",
   "                       clear, turn core display on/off or set -v option to nnn\n",
 #endif
@@ -125,13 +125,13 @@ char   *helpText[] = {
   "(rem)ark string        macro comment\n",
   "(res)et                terminate macro/command chain processing\n",
   "(se)arch pattern       search for wildcarded pattern in core\n",
-#if !defined(__MAC__) && !defined(XWINGRAPHX)
+#if !defined(__MAC__) && !defined(XWINGRAPHX) && !defined(SDLGRAPHX)
   "(sh)ell [command]      execute OS command\n",
 #endif
   "(sk)ip [count]         execute [count] steps silently\n",
   "(s)tep *               execute next queued instruction\n",
 #if defined(DOSGRXGRAPHX) || defined(DOSTXTGRAPHX) || defined(LINUXGRAPHX) \
-    || defined(XWINGRAPHX)
+    || defined(XWINGRAPHX) || defined(SDLGRAPHX)
   "(sw)itch [1|2]         switch to left (1), right (2), or other cdb panel\n",
 #endif
   "(th)read *             step through current thread\n",
@@ -190,7 +190,7 @@ char   *cannotAllocateScreenBuffers = "Cannot allocate textmode screen buffers\n
 
 /* strings shared between displays */
 #if defined(DOSTXTGRAPHX) || defined(DOSGRXGRAPHX) || defined(LINUXGRAPHX) \
-    || defined(XWINGRAPHX)
+    || defined(XWINGRAPHX) || defined(SDLGRAPHX) || defined(STDGRAPHX)
 char   *pressAnyKey = "Press any key ..";
 #endif
 #ifdef DOSGRXGRAPHX
@@ -228,6 +228,18 @@ char   *privateMap = "Can't allocate color \"%s\"; switching to private colormap
 char   *invalidGeom = "Invalid geometry specification\n";
 #endif                                /* XWINGRAPHX */
 
+/* sdldisp.c strings here */
+#ifdef SDLGRAPHX
+char   *badModeString = "Invalid mode string";
+char   *failedSDLInit = "Failed to initialise SDL";
+char   *errDisplayOpen = "Couldn't open display";
+char   *errSpriteConv = "Couldn't convert sprite to display format";
+char   *errSpriteColKey = "Couldn't set colorkey for sprite";
+char   *errSpriteSurf = "Couldn't create surface for sprite";
+char   *errSpriteFill = "Failed to fill sprite";
+char   *errorHeader = "Error: %s";
+#endif                                /* SDLGRAPHX */
+
 /* pmars.c */
 
 #if defined(__BORLANDC__) && defined(CHECK386)
@@ -344,7 +356,17 @@ char   *credits_screen3 =
 char   *credits_screen3 =
 "Linux/SVGA display version by Martin Maierhofer\n";
 #else
+#ifdef SDLGRAPHX
+char   *credits_screen3 =
+"SDL display version by M Joonas Pihlaja\n";
+#else
+#ifdef STDGRAPHX
+char   *credits_screen3 =
+"Stdio non-display display example by M Joonas Pihlaja\n";
+#else
 char   *credits_screen3 = "";
+#endif                                /* STDGRAPHX */
+#endif 		                      /* SDLGRAPHX */
 #endif                                /* LINUXGRAPHX */
 #endif                                /* MACGRAPHX */
 #endif                                /* DOSTXTGRAPHX */
@@ -404,7 +426,7 @@ char   *optFixedSeries = "Fixed position series";
 char   *optFixedPosition = "Fixed position of warrior #2";
 char   *optSort = "Sort result output by score";
 #if defined(DOSTXTGRAPHX) || defined(DOSGRXGRAPHX) || defined(LINUXGRAPHX)\
-    || defined(XWINGRAPHX)
+    || defined(XWINGRAPHX) || defined(SDLGRAPHX) || defined(STDGRAPHX)
 char   *optView = "Coreview mode [103]";
 #endif
 char   *optScoreFormula = "Score formula $ [(W*W-1)/S]";
